/*
 * AllupImpl.hh
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file AllupImpl.hh
 *
 * Header file for the AllupImpl class.
 */

#ifndef _allup_impl_hh
#define _allup_impl_hh

#include <map>
#include <string>

using namespace std;

#include "AllupS.h"

/**
 * A straight-forward implementation of the edu::utah::pces::Allup interface.
 *
 * @sa FactoryLibrary_ltdl
 */
class AllupImpl : public virtual POA_edu::utah::pces::Allup
{

public:

    /**
     * Construct an AllupImpl with the default values.
     *
     * @param my_poa The POA this object was activated under.
     */
    AllupImpl(PortableServer::POA_ptr my_poa);

    /**
     * Deconstruct an AllupImpl.
     */
    virtual ~AllupImpl(void);

    /** @copydoc edu::utah::pces::Allup::OpenLibrary */
    virtual edu::utah::pces::FactoryLibrary_ptr OpenLibrary(const char *name)
	throw (edu::utah::pces::NoSuchLibrary,
	       CORBA::SystemException);

    /** @copydoc edu::utah::pces::Allup::Libraries */
    virtual edu::utah::pces::FactoryLibraryList *Libraries(void)
	throw (CORBA::SystemException);

    /** @copydoc edu::utah::pces::Allup::Shutdown */
    virtual void Shutdown(void)
	throw (CORBA::SystemException);

    /**
     * @exception CORBA::BAD_INV_ORDER when called.  This object should always
     * be activated under a single threaded POA.
     */
    virtual PortableServer::POA_ptr _default_POA(void)
	throw (CORBA::SystemException)
    {
	throw CORBA::BAD_INV_ORDER();
    };

private:

    /**
     * The 'name->library' map object type.
     */
    typedef map<string, edu::utah::pces::FactoryLibrary_var> library_map_t;

    /**
     * Map of currently open library names to their object references.
     */
    library_map_t ai_Libraries;

    /**
     * The POA this object was activated under and any new objects should be
     * activated under.
     */
    PortableServer::POA_var ai_POA;
    
};

#endif
