/*
 * timesFile.h
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file timesFile.h
 *
 * Helper functions for testing with the rk_stub library.
 *
 * @sa rk_stub.c
 */

#ifndef _times_file_h
#define _times_file_h

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Special value used to terminate an array of float values.
 */
#define TIMES_FILE_TERMINATOR -1.0

/**
 * Make a file in the current directory with the given name whose contents are
 * the given array of floats.
 *
 * @sa rk_resource_set_create
 *
 * @param name The name of the file.
 * @param values The array of values to put in the new file, terminated by the
 *               TIMES_FILE_TERMINATOR value.  Because these values are
 *               expected to be used by the rk_stub code, they should be
 *               between 0.0 and 150.0, inclusive.
 * @return True if the file was created successfully, false otherwise.
 */
int tfMakeTimesFile(const char *name, const float values[]);

#ifdef __cplusplus
}
#endif

#endif
