/*
 * StrictPolicyCallbackImpl.cc
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file StrictPolicyCallbackImpl.cc
 *
 * Implementation of the StrictPolicyCallbackImpl class.
 */

#include "config.h"

#include <iostream>
#include <assert_pp.h>

#include "ManagerImpl.hh"
#include "StrictPolicyCallbackImpl.hh"

using namespace std;

StrictPolicyCallbackImpl::StrictPolicyCallbackImpl(
	BrokerPolicies::StrictPolicy_ptr sp) :
    spci_Policy(sp)
{
    int argc = 0;
    
    this->spci_ORB = CORBA::ORB_init(argc, (char **)NULL);
}

StrictPolicyCallbackImpl::~StrictPolicyCallbackImpl(void)
{
}

void StrictPolicyCallbackImpl::sendMessage(const char *msg)
    throw (CORBA::SystemException)
{
    require(msg != NULL);
    
    cerr << msg << endl;
}

void StrictPolicyCallbackImpl::SetPriorityOf(const char *task_name,
					     CORBA::Short priority)
    throw (CORBA::SystemException)
{
    Broker::Task_ptr task;
    Broker::TaskList *tl;
    
    if( task_name == NULL )
    {
	throw CORBA::BAD_PARAM();
    }
    if( CORBA::is_nil(this->spci_Policy.in()) )
    {
	throw CORBA::BAD_INV_ORDER();
    }

    tl = this->spci_Policy->GetTaskList();
    task = ManagerImpl::ResolveTask(this->spci_ORB, *tl, task_name);
    if( CORBA::is_nil(task) )
    {
	throw CORBA::BAD_PARAM();
    }
    this->spci_Policy->SetTaskPriority(task, priority);
}

CORBA::Short StrictPolicyCallbackImpl::GetPriorityOf(const char *task_name)
    throw (CORBA::SystemException)
{
    Broker::Task_ptr task;
    Broker::TaskList *tl;
    CORBA::Short retval;
    
    if( task_name == NULL )
    {
	throw CORBA::BAD_PARAM();
    }
    if( CORBA::is_nil(this->spci_Policy.in()) )
    {
	throw CORBA::BAD_INV_ORDER();
    }

    tl = this->spci_Policy->GetTaskList();
    task = ManagerImpl::ResolveTask(this->spci_ORB, *tl, task_name);
    if( CORBA::is_nil(task) )
    {
	throw CORBA::BAD_PARAM();
    }
    retval = this->spci_Policy->GetTaskPriority(task);
    
    return( retval );
}
