/*
 * MinMaxTaskAdvocate.hh
 *
 * Copyright (c) 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file MinMaxTaskAdvocate.hh
 *
 * Header file for the MinMaxTaskAdvocate class.
 */

#ifndef _min_max_task_advocate_hh
#define _min_max_task_advocate_hh

#include <RealTimeTaskDelegateImpl.hh>

/**
 * An advocate that bounds an advice to a user-defined minimum and maximum.
 */
class MinMaxTaskAdvocate : public virtual RealTimeTaskDelegateImpl
{

public:
    
    /** Default constructor. */
    MinMaxTaskAdvocate(void);

    /** Destructor. */
    virtual ~MinMaxTaskAdvocate(void);
    
    /**
     * @copydoc BrokerDelegates::Delegate::SetDelegateAttribute
     *
     * Currently supported 'id' values are:
     *
     * @li @e minimum The minimum advice to be reported by this advocate.
     * @li @e maximum The maximum advice to be reported by this advocate.
     */
    virtual void SetDelegateAttribute(const char *id,
				      const CORBA::Any &value)
	throw (CORBA::SystemException);

    /**
     * @copydoc BrokerDelegates::Delegate::GetDelegateAttribute
     *
     * Currently supported 'id' values are:
     *
     * @li @e minimum The minimum advice to be reported by this advocate.
     * @li @e maximum The maximum advice to be reported by this advocate.
     */
    virtual CORBA::Any *GetDelegateAttribute(const char *id)
	throw (CORBA::SystemException);
    
    /** @copydoc Broker::RealTimeTask::PassCPU */
    virtual Broker::CPUReserve PassCPU(Broker::RealTimeTask_ptr rtt,
				       const Broker::CPUReserve &status,
				       const Broker::CPUReserve &advice,
				       const Broker::KeyedReportParameters &krp)
	throw (CORBA::SystemException);

private:

    /**
     * Minimum advice to be reported by this advocate.
     */
    CORBA::ULong mm_Minimum;

    /**
     * Maximum advice to be reported by this advocate.
     */
    CORBA::ULong mm_Maximum;
    
};

#endif
