/*
 * QuoAdvocate.hh
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file QuoAdvocate.hh
 *
 * Header file for the QuoAdvocate class.
 */

#ifndef _quo_advocate_hh
#define _quo_advocate_hh

#include <iostream>

#include <RealTimeTaskDelegateImpl.hh>
#include <quo/quoC.h>

/**
 * A decorator that sends the status and advice values to QuO system
 * conditions.
 */
class QuoAdvocate : public virtual RealTimeTaskDelegateImpl
{

public:

    /** Default constructor. */
    QuoAdvocate(void);

    /** Destructor. */
    virtual ~QuoAdvocate(void);

    /**
     * @copydoc BrokerDelegates::Delegate::SetDelegateAttribute
     *
     * Currently supported 'id' values are:
     *
     * @li @e status-sc The syscond to send the status value to.
     * @li @e advice-sc The syscond to send the advice value to.
     */
    virtual void SetDelegateAttributeObject(const char *id,
					    const CORBA::Object_ptr value)
	throw (CORBA::SystemException);

    /**
     * @copydoc BrokerDelegates::Delegate::GetDelegateAttribute
     *
     * Currently supported 'id' values are:
     *
     * @li @e status-sc The syscond to send the status value to.
     * @li @e advice-sc The syscond to send the advice value to.
     */
    virtual CORBA::Any *GetDelegateAttribute(const char *id)
	throw (CORBA::SystemException);

    /** @copydoc Broker::RealTimeTask::PassCPU */
    virtual Broker::CPUReserve PassCPU(Broker::RealTimeTask_ptr rtt,
				       const Broker::CPUReserve &status,
				       const Broker::CPUReserve &advice,
				       const Broker::KeyedReportParameters &krp)
	throw (CORBA::SystemException);

protected:

    /**
     * The QuO system condition that should be updated with the 'status' value
     * given in ReportCPU.
     */
    quo::ValueSC_var eta_Status;
    
    /**
     * The QuO system condition that should be updated with the 'advice' value
     * given in ReportCPU.
     */
    quo::ValueSC_var eta_Advice;
    
};

#endif
