/*
 * GlacialTaskAdvocate.cc
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file GlacialTaskAdvocate.cc
 *
 * Implementation of the GlacialTaskAdvocate class.
 */

#include "config.h"

#include "GlacialTaskAdvocate.hh"

GlacialTaskAdvocate::GlacialTaskAdvocate(void)
{
    this->gta_LastAdvice = 0;
}

GlacialTaskAdvocate::~GlacialTaskAdvocate(void)
{
}

Broker::CPUReserve GlacialTaskAdvocate::PassCPU(Broker::RealTimeTask_ptr rtt,
						const Broker::CPUReserve &status,
						const Broker::CPUReserve &advice,
						const Broker::KeyedReportParameters &krp)
    throw (CORBA::SystemException)
{
    Broker::CPUReserve new_advice = advice;
    CORBA::ULong change;

    if( CORBA::is_nil(this->dm_RemoteObject.in()) )
    {
	throw CORBA::BAD_INV_ORDER();
    }
    
    if( new_advice.Compute > this->gta_LastAdvice )
    {
	change = new_advice.Compute - this->gta_LastAdvice;
	new_advice.Compute = this->gta_LastAdvice + (change / 4) + 10;
    }
    else
    {
	change = this->gta_LastAdvice - new_advice.Compute;
	new_advice.Compute = this->gta_LastAdvice - (change / 4);
    }
    this->gta_LastAdvice = new_advice.Compute;
    return this->RealTimeTaskDelegateImpl::PassCPU(rtt,
						   status,
						   new_advice,
						   krp);
}
